@@ -25,13 +25,19 @@
 
 int main () 
 {
-  int ierr;
-  ierr = giza_open_device("?","test");
+  int id;
+  id = giza_open_device("?","test");
   giza_stop_prompting();
   giza_close_device();
 
-  ierr = giza_open_device("/xw","test");
+  id = giza_open_device("/xw","test");
   giza_stop_prompting();
   giza_close_device();
 
+  /* open_device should return a positive integer */
+  if (id <= 0) {
+    return 1;
+  } else {
+    return 0;
+  }
 }
